@@ -5,7 +5,6 @@ use warnings;
 
 use CGI ':standard';
 
-$SIG{__DIE__} = sub { print "DIED!\n" };
-$SIG{__WARN__} = sub { print "WARNED!\n" };
+$SIG{USR1} = 'IGNORE';
 
 print header;
